asr.database.fromtree
=====================

.. automodule:: asr.database.fromtree

   
   
   .. rubric:: Functions

   
   .. autofunction:: collect_file
   .. autofunction:: collect_folder
   .. autofunction:: collect_folders
   .. autofunction:: collect_links_to_child_folders
   .. autofunction:: delegate_to_njobs
   .. autofunction:: get_key_value_pairs
   .. autofunction:: get_material_uid
   .. autofunction:: make_data_identifiers
   .. autofunction:: parse_key_descriptions
   .. autofunction:: recurse_through_folders
   
   

   
   
   

   
   
   .. rubric:: Exceptions

   
   .. autoexception:: MissingUIDS
   
   